/*******************************************************************************
 * Copyright (c) 2011 Ericsson
 * 
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *******************************************************************************/
package org.eclipse.linuxtools.ust.sample2.ui.model;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerComparator;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfBaseColumnData;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfBaseColumnDataProvider;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfStatistics;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfStatisticsTreeNode;
import org.eclipse.swt.SWT;

public class NewStatisticsColumnDataProvider extends TmfBaseColumnDataProvider {

    protected final static String TIME_COUNT_COLUMN = "Longest Latency"; //$NON-NLS-1$
    protected final static String TIME_COLUMN_TIP = "Longest Latency for give start event"; //$NON-NLS-1$
    
    public NewStatisticsColumnDataProvider() {
        super();
        fColumnData.add(new TmfBaseColumnData(TIME_COUNT_COLUMN, 125, SWT.LEFT, TIME_COLUMN_TIP, new ColumnLabelProvider() {
            @Override
            public String getText(Object element) {
                TmfStatisticsTreeNode node = (TmfStatisticsTreeNode) element;
                if (!fFolderLevels.contains(node.getKey())) {
                    TmfStatistics value = node.getValue();
                    if (value instanceof NewStatistics) {
                        long longValue = ((NewStatistics)node.getValue()).latency;
                        if (longValue != 0) {
                            return String.valueOf(longValue);
                        }
                        return ""; //$NON-NLS-1$
                    }
                }
                return ""; //$NON-NLS-1$
            }
        }, new ViewerComparator() {
            @Override
            public int compare(Viewer viewer, Object e1, Object e2) {
                TmfStatisticsTreeNode n1 = (TmfStatisticsTreeNode) e1;
                TmfStatisticsTreeNode n2 = (TmfStatisticsTreeNode) e2;

                TmfStatistics value1 = n1.getValue();
                TmfStatistics value2 = n2.getValue();
                if (value1 instanceof NewStatistics && value2 instanceof NewStatistics) {
                    return (int) (((NewStatistics) value1).latency - ((NewStatistics) value2).latency);
                }

                return 0;
                
            }
        }, null));
    }
}
