/*******************************************************************************
 * Copyright (c) 2011 Ericsson
 * 
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *******************************************************************************/
package org.eclipse.linuxtools.ust.sample2.ui.model;

import org.eclipse.linuxtools.lttng.event.LttngEvent;
import org.eclipse.linuxtools.tmf.event.TmfEvent;
import org.eclipse.linuxtools.tmf.ui.views.statistics.ITmfExtraEventInfo;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfBaseStatisticsTree;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfStatistics;
import org.eclipse.linuxtools.tmf.ui.views.statistics.model.TmfStatisticsTreeNode;
import org.eclipse.linuxtools.tmf.util.TmfFixedArray;

public class NewStatisticsModel extends TmfBaseStatisticsTree {

    private LatencyCalculator fLatencyCalulator;

    public NewStatisticsModel() {
        super();
        fLatencyCalulator = new LatencyCalculator();
        fLatencyCalulator.initialize();
    }

    @Override
    public void increase(TmfEvent event, ITmfExtraEventInfo extraInfo, int values) {
        
        if (event instanceof LttngEvent) {

            long latency = fLatencyCalulator.calculate((LttngEvent)event);

            if (latency >= 0) {
                TmfFixedArray<String>[] paths = getNormalPaths(event, extraInfo);

                for (TmfFixedArray<String> path : paths) {
                    TmfStatistics current = getOrCreate(path).getValue();
                    if (current instanceof NewStatistics) {
                        ((NewStatistics)current).latency = Math.max(((NewStatistics)current).latency, latency);
                    }         
                }
                paths = getTypePaths(event, extraInfo);
                for (TmfFixedArray<String> path : paths) {
                    TmfStatistics current = getOrCreate(path).getValue();
                    if (current instanceof NewStatistics) {
                        ((NewStatistics)current).latency = Math.max(((NewStatistics)current).latency, latency);
                    }         
                }
            }
        }
        else {
            return;
        }
    }

    @Override
    public TmfStatisticsTreeNode getOrCreate(final TmfFixedArray<String> path) {
        TmfStatisticsTreeNode current = fNodes.get(path);
        if (current == null) {
            registerName(path);
            current = new NewStatisticsTreeNode(path, this);
            fNodes.put(path, current);
        }
        return current;
    }
    
    @Override
    public void reset(final TmfFixedArray<String> path) {
    	super.reset(path);
    	fLatencyCalulator.initialize();
    }
}    

